@@ -41,14 +41,14 @@ BasicSettings::BasicSettings(LXQt::Settings* settings, QWidget *parent) :
 
     restoreSettings();
 
-    connect(topLeftRB,      SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(topCenterRB,    SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(topRightRB,     SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(centerLeftRB,   SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(centerRightRB,  SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(bottomLeftRB,   SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(bottomCenterRB, SIGNAL(clicked()), this, SLOT(updateNotification()));
-    connect(bottomRightRB,  SIGNAL(clicked()), this, SLOT(updateNotification()));
+    connect(topLeftRB,      &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(topCenterRB,    &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(topRightRB,     &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(centerLeftRB,   &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(centerRightRB,  &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(bottomLeftRB,   &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(bottomCenterRB, &QRadioButton::clicked, this, &BasicSettings::updateNotification);
+    connect(bottomRightRB,  &QRadioButton::clicked, this, &BasicSettings::updateNotification);
 
     LXQt::Notification *serverTest = new LXQt::Notification(QString(), this);
     serverTest->queryServerInfo();
@@ -57,12 +57,12 @@ BasicSettings::BasicSettings(LXQt::Settings* settings, QWidget *parent) :
     QTimer *saneQueryTimeout = new QTimer(this);
     saneQueryTimeout->setSingleShot(true);
     saneQueryTimeout->start(200);
-    connect(saneQueryTimeout, &QTimer::timeout, [this]() {
+    connect(saneQueryTimeout, &QTimer::timeout, warningLabel, [this]() {
                 warningLabel->setText(tr("<b>Warning:</b> notifications daemon is slow to respond.\n"
                         "Keep trying to connect…"));
             });
 
-    connect(serverTest, &LXQt::Notification::serverInfoReady, [this, serverTest, saneQueryTimeout]() {
+    connect(serverTest, &LXQt::Notification::serverInfoReady, this, [this, serverTest, saneQueryTimeout]() {
             QString serverName = serverTest->serverInfo().name;
             if (serverName != QL1S("lxqt-notificationd"))
             {
@@ -80,9 +80,7 @@ BasicSettings::BasicSettings(LXQt::Settings* settings, QWidget *parent) :
         });
 }
 
-BasicSettings::~BasicSettings()
-{
-}
+BasicSettings::~BasicSettings() = default;
 
 void BasicSettings::restoreSettings()
 {
