@@ -4,69 +4,84 @@
 <context>
     <name>AdvancedSettings</name>
     <message>
-        <location filename="../advancedsettings.ui" line="17"/>
+        <location filename="../advancedsettings.ui" line="67"/>
         <source>Sizes</source>
         <translation>Medidas</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="25"/>
+        <location filename="../advancedsettings.ui" line="75"/>
         <source>Width:</source>
         <translation>Largo:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="32"/>
-        <location filename="../advancedsettings.ui" line="56"/>
+        <location filename="../advancedsettings.ui" line="82"/>
+        <location filename="../advancedsettings.ui" line="106"/>
         <source> px</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="49"/>
+        <location filename="../advancedsettings.ui" line="99"/>
         <source>Spacing:</source>
         <translation>Espazado:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="68"/>
+        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Duración</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="80"/>
+        <location filename="../advancedsettings.ui" line="130"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Algunhas notificacións estabelecen a súa propia duración en pantalla.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="92"/>
+        <location filename="../advancedsettings.ui" line="142"/>
         <source>Default duration:</source>
         <translation>Duración predeterminada:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="99"/>
+        <location filename="../advancedsettings.ui" line="149"/>
         <source> sec</source>
         <translation> seg</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="127"/>
+        <location filename="../advancedsettings.ui" line="177"/>
+        <source>Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="183"/>
+        <source>When unchecked the notification will always show on primary screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="186"/>
+        <source>Show notifications on screen with the mouse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="17"/>
         <source>Unattended Notifications</source>
         <translation>Notificacións desatendidas</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="135"/>
+        <location filename="../advancedsettings.ui" line="25"/>
         <source>How many to save:</source>
         <translation>Cantos hai para gardar:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
-        <location filename="../advancedsettings.ui" line="159"/>
+        <location filename="../advancedsettings.ui" line="39"/>
+        <location filename="../advancedsettings.ui" line="49"/>
         <source>Application name is on the top of notification.</source>
         <translation>O nome da aplicación atópase na parte superior da notificación.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="152"/>
+        <location filename="../advancedsettings.ui" line="42"/>
         <source>Ignore these applications:</source>
         <translation>Ignorar estas aplicacións:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="162"/>
+        <location filename="../advancedsettings.ui" line="52"/>
         <source>app1,app2,app3</source>
         <translation>apli1,apli2,apli3</translation>
     </message>
@@ -84,26 +99,32 @@
         <translation>Posición na pantalla</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="56"/>
+        <location filename="../basicsettings.cpp" line="61"/>
+        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
+Keep trying to connect…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="70"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Aviso:&lt;/b&gt; Non hai ningún servizo de notificación en execución.
 Empregarase un método alternativo.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="59"/>
+        <location filename="../basicsettings.cpp" line="73"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Aviso:&lt;/b&gt; Hai un servizo de notificacións de terceiros (%1) en execución.
 Estes axustes non lle afectarán!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="112"/>
+        <location filename="../basicsettings.cpp" line="131"/>
         <source>Notification demo </source>
         <translation>Proba de notificación </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="113"/>
+        <location filename="../basicsettings.cpp" line="132"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Isto é unha notificación de proba.
