@@ -50,9 +50,9 @@ Notification::Notification(const QString &application,
                            const QStringList& actions, const QVariantMap& hints,
                            QWidget *parent)
     : QWidget(parent),
-      m_timer(0),
+      m_timer(nullptr),
       m_linkHovered(false),
-      m_actionWidget(0),
+      m_actionWidget(nullptr),
       m_icon(icon),
       m_timeout(timeout),
       m_actions(actions),
@@ -91,11 +91,20 @@ void Notification::setValues(const QString &application,
     //  - "image-data"
     //  - "image-path"
     //  - app_icon parameter
-    //  - for compatibility reason, "icon_data"
-    if (!hints[QL1S("image_data")].isNull())
+    //  - for compatibility reason, "icon_data", "image_data" and "image_path"
+
+    if (!hints[QL1S("image-data")].isNull())
+    {
+        m_pixmap = getPixmapFromHint(hints[QL1S("image-data")]);
+    }
+    else if (!hints[QL1S("image_data")].isNull())
     {
         m_pixmap = getPixmapFromHint(hints[QL1S("image_data")]);
     }
+    else if (!hints[QL1S("image-path")].isNull())
+    {
+        m_pixmap = getPixmapFromHint(hints[QL1S("image-path")]);
+    }
     else if (!hints[QL1S("image_path")].isNull())
     {
         m_pixmap = getPixmapFromString(hints[QL1S("image_path")].toString());
@@ -180,7 +189,7 @@ void Notification::setValues(const QString &application,
     }
 
     // Actions
-    if (actions.count() && m_actionWidget == 0)
+    if (actions.count() && m_actionWidget == nullptr)
     {
         if (actions.count()/2 < 4)
             m_actionWidget = new NotificationActionsButtonsWidget(actions, this);
@@ -274,19 +283,19 @@ QPixmap Notification::getPixmapFromString(const QString &str) const
     }
 }
 
-void Notification::enterEvent(QEvent * event)
+void Notification::enterEvent(QEvent * /*event*/)
 {
     if (m_timer)
         m_timer->pause();
 }
 
-void Notification::leaveEvent(QEvent * event)
+void Notification::leaveEvent(QEvent * /*event*/)
 {
     if (m_timer)
         m_timer->resume();
 }
 
-bool Notification::eventFilter(QObject *obj, QEvent *event)
+bool Notification::eventFilter(QObject * /*obj*/, QEvent * event)
 {
     // Catch mouseReleaseEvent on child labels if a link is not currently being hovered.
     //
@@ -300,7 +309,7 @@ bool Notification::eventFilter(QObject *obj, QEvent *event)
     return false;
 }
 
-void Notification::linkHovered(QString link)
+void Notification::linkHovered(const QString& link)
 {
     m_linkHovered = !link.isEmpty();
 }
@@ -317,7 +326,8 @@ void Notification::mouseReleaseEvent(QMouseEvent * event)
         return;
     }
 
-    for (WId i : KWindowSystem::stackingOrder())
+    const auto ids = KWindowSystem::stackingOrder();
+    for (const WId &i : ids)
     {
         KWindowInfo info = KWindowInfo(i, NET::WMName | NET::WMVisibleName);
         appName = info.name();
